import { getServiceLogger } from '../utils/logging'
import api from '../api'
import { API_CONFIG } from '../config'
import { timeout } from '../utils/timing'

const PORT = API_CONFIG.port || 8080

const log = getServiceLogger()

const server = api.listen(PORT, () => {
  log.info(`Listening on port ${PORT}`)
})

process.on('SIGTERM', async () => {
  log.warn('Detected SIGTERM signal, started exiting!')
  await new Promise<void>((resolve) => {
    server.close((err) => {
      if (err) {
        log.error(err, 'Error while closing server!')
        resolve()
      } else {
        log.info('Server closed successfully!')
        resolve()
      }
    })
  })

  log.info('Exiting in 5 seconds...')
  await timeout(5000)
  process.exit(0)
})
